"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Filters = void 0;
const package_json_1 = require("../../package.json");
const getBuffer_1 = require("../utils/getBuffer");
/**
 * Applies filters to a given image url
 * @example
 * const image = new StrangeFilters('Strange API token')
 * const blurredImage = await image.blur('Image Url', 6)
 */
class Filters {
    opts;
    constructor(token) {
        this.opts = {
            headers: {
                Authorization: `Bearer ${token}`,
            },
        };
    }
    /**
     * Blurs an image
     * @param image The image url
     * @param level Intensity of the blur
     */
    async blur(image, level) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/blur`);
        if (image)
            endpoint.searchParams.append("image", image);
        if (level)
            endpoint.searchParams.append("level", level.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Brightens an image
     * @param image The image url
     * @param amount Brightness amount
     */
    async brighten(image, amount) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/brighten`);
        if (image)
            endpoint.searchParams.append("image", image);
        if (amount)
            endpoint.searchParams.append("amount", amount.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Burns an image
     * @param image The image url
     * @param level Burn intensity
     */
    async burn(image, level) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/burn`);
        if (image)
            endpoint.searchParams.append("image", image);
        if (level)
            endpoint.searchParams.append("level", level.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Darkens an image
     * @param image The image url
     * @param amount Darkness amount
     */
    async darken(image, amount) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/darken`);
        if (image)
            endpoint.searchParams.append("image", image);
        if (amount)
            endpoint.searchParams.append("amount", amount.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Applies Deepfry filter to an image
     * @param image The image url
     */
    async deepfry(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/deepfry`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Distorts an image
     * @param image The image url
     * @param level The level of distortion
     */
    async distort(image, level) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/distort`);
        if (image)
            endpoint.searchParams.append("image", image);
        endpoint.searchParams.append("level", level.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Applies Greyscale filter to an image
     * @param image The image url
     */
    async greyscale(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/greyscale`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Inverts colors of an image
     * @param image The image url
     */
    async invert(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/invert`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Pixilates an image
     * @param image The image url
     * @param pixels Pixels
     */
    async pixelate(image, pixels) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/pixelate`);
        if (image)
            endpoint.searchParams.append("image", image);
        if (pixels)
            endpoint.searchParams.append("pixels", pixels.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Applies sepia filter to an image
     * @param image The image url
     */
    async sepia(image) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/sepia`);
        if (image)
            endpoint.searchParams.append("image", image);
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Adds sharpness filter to your image
     * @param image The image url
     * @param level Sharpness intensity
     */
    async sharpen(image, level) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/sharpen`);
        if (image)
            endpoint.searchParams.append("image", image);
        if (level)
            endpoint.searchParams.append("level", level.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
    /**
     * Adds Threshold filter to your image
     * @param image The image url
     * @param amount Threshold amount
     */
    async threshold(image, amount) {
        const endpoint = new URL(`${package_json_1.baseUrl}/filters/threshold`);
        if (image)
            endpoint.searchParams.append("image", image);
        endpoint.searchParams.append("amount", amount?.toString());
        return await (0, getBuffer_1.getBuffer)(endpoint.href, this.opts);
    }
}
exports.Filters = Filters;
